@@ -1,4 +1,4 @@
 from .plotsize import Sizing
 from .configuration import BackendConfiguration
 from .utils import save, set_text
-from .main import Controller
\ No newline at end of file
+from .main import Plotex
\ No newline at end of file
